@@ -190,9 +190,9 @@ class Result:
             for direct in ["up","down"]:
                 for pp in r.get(direct, {'params':{}})['params']:
                     if pp in params[direct]:
-                        params[direct][pp].append(r[direct]['params'][pp])
+                        params[direct][pp] = np.vstack([params[direct][pp],r[direct]['params'][pp]])
                     else:
-                        params[direct][pp] = [r[direct]['params'][pp]]
+                        params[direct][pp] = np.array([r[direct]['params'][pp]])
         return np.array(t),params
            
     def plotResult(self, sample, pixelID, resultID, globalTime=False, ax=None, axb=None, col='C0', colb='C1', V=True, I=True, hyst=False, **kargs):
